@@ -28,6 +28,10 @@
 #include <gmodule.h>
 #include <glib/gstdio.h>
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include "gui.h"
 #include "upnp.h"
 #include "main.h"
