@@ -22,7 +22,10 @@
 
 #include <string.h>
 #include <stdlib.h>
+
+#ifdef HAVE_CONFIG_H
 #include <config.h>
+#endif
 
 #include <gmodule.h>
 #include <glib/gi18n.h>
